@@ -12,10 +12,9 @@ log = logging.getLogger("aurevent")
 
 
 class AutoRepr:
-    @staticmethod
-    def repr(obj):
+    def __repr__(self):
         items = []
-        for prop, value in obj.__dict__.items():
+        for prop, value in self.__dict__.items():
             try:
                 item = "%s = %r" % (prop, value)
                 assert len(item) < 100
@@ -23,18 +22,33 @@ class AutoRepr:
                 item = "%s: <%s>" % (prop, value.__class__.__name__)
             items.append(item)
 
-        return "%s(%s)" % (obj.__class__.__name__, ', '.join(items))
+        return "%s(%s)" % (self.__class__.__name__, ', '.join(items))
 
-    def __init__(self, cls):
-        cls.__repr__ = AutoRepr.repr
-        self.cls = cls
-
-    def __call__(self, *args, **kwargs):
-        return self.cls(*args, **kwargs)
+    # class AutoRepr:
 
 
-@AutoRepr
-class Event:
+#     @staticmethod
+#     def repr(obj):
+#         items = []
+#         for prop, value in obj.__dict__.items():
+#             try:
+#                 item = "%s = %r" % (prop, value)
+#                 assert len(item) < 100
+#             except:
+#                 item = "%s: <%s>" % (prop, value.__class__.__name__)
+#             items.append(item)
+#
+#         return "%s(%s)" % (obj.__class__.__name__, ', '.join(items))
+#
+#     def __init__(self, cls):
+#         cls.__repr__ = AutoRepr.repr
+#         self.cls = cls
+#
+#     def __call__(self, *args, **kwargs):
+#         return self.cls(*args, **kwargs)
+
+
+class Event(AutoRepr):
     def __init__(self, __event_name: str, *args, **kwargs):
         self.name: str = __event_name.lower()
         self.args: ty.Tuple = args
@@ -66,8 +80,7 @@ class EventWaiter:
     check: ty.Callable[[Event], ty.Coroutine[bool]]
 
 
-@AutoRepr
-class EventMuxer:
+class EventMuxer(AutoRepr):
     __router = None
 
     def __init__(self, name):
@@ -107,7 +120,7 @@ class EventMuxer:
             self.__router = router
 
 
-class EventRouter:
+class EventRouter(AutoRepr):
     def __init__(self, name: str, parent: EventRouter = None):
         self.name = name.lower()
         self.parent = parent
